@@ -76,8 +76,10 @@ def company(symbol, external=False, vprint=False):
     :param symbol: The ticker or symbol of the stock you would like to request.
     :type symbol: string, required
     """
-    url = replace_url_var(IEX_COMPANY_URL, symbol=symbol)
-    return get_iex_json_request(url, external=external, vprint=vprint)
+    instance = iexCommon('stock', symbol, 'company', external=external).pre_execute()
+    return instance.execute()
+    # url = replace_url_var(IEX_COMPANY_URL, symbol=symbol)
+    # return get_iex_json_request(url, external=external, vprint=vprint)
 
 
 #   Delayed Quote
